package com.ruoyi.base.service.impl;

import java.util.List;
import java.util.stream.Collectors;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.ruoyi.common.exception.ServiceException;
import com.ruoyi.common.utils.DateUtils;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ruoyi.member.vo.MemberUniVO;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.ruoyi.base.mapper.BaseCategoryMapper;
import com.ruoyi.base.domain.BaseCategory;
import com.ruoyi.base.service.IBaseCategoryService;

/**
 * 分类树-各种分类属性结构Service业务层处理
 * 
 * @author vinjor-m
 * @date 2025-03-17
 */
@Service
public class BaseCategoryServiceImpl extends ServiceImpl<BaseCategoryMapper,BaseCategory>  implements IBaseCategoryService
{
    @Autowired
    private BaseCategoryMapper baseCategoryMapper;

    @Override
    public IPage<BaseCategory> queryListPage(BaseCategory pageReqVO, Page<BaseCategory> page) {
        return baseCategoryMapper.queryListPage(pageReqVO, page);
    }

    /**
     * 根据code查询字典
     *
     * @param code
     * @return java.util.List<com.ruoyi.base.domain.BaseCategory>
     * @author vinjor-M
     * @date 11:32 2025/3/18
     **/
    @Override
    public List<BaseCategory> selectByCode(String code) {
        return this.list(new LambdaQueryWrapper<BaseCategory>().eq(BaseCategory::getCode,code));
    }

    /**
     * 根据code查分类字典--列表
     *
     * @param code     编码
     * @param isSystem 是否系统级
     * @return java.util.List<com.ruoyi.base.domain.BaseCategory>
     * @author vinjor-M
     * @date 17:01 2025/3/25
     **/
    @Override
    public List<BaseCategory> listByParentCode(String code, Integer isSystem) {
        List<BaseCategory> list = this.selectByCode(code);
        if(list.isEmpty()){
            throw new ServiceException("未查询到该字典项!");
        }
        LambdaQueryWrapper<BaseCategory> queryWrapper = new LambdaQueryWrapper<>();
        queryWrapper.eq(BaseCategory::getPid,list.get(0).getId());
        if(null!=isSystem){
            queryWrapper.eq(BaseCategory::getIsSystem,isSystem);
        }
        queryWrapper.orderByAsc(BaseCategory::getSort);
        return list(queryWrapper);
    }

    /**
     * 查询列表
     *
     * @param code     编码
     * @param isSystem 是否系统级
     * @return java.util.List<com.ruoyi.member.vo.MemberUniVO>
     * @author PQZ
     * @date 14:43 2025/4/3
     **/
    @Override
    public List<MemberUniVO> uniListByParentCode(String code, Integer isSystem) {
        List<BaseCategory> list = listByParentCode(code, isSystem);
        return list.stream().map(item -> new MemberUniVO(item.getCode(),item.getTitle())).collect(Collectors.toList());
    }
}
