package com.ruoyi.member.service.impl;

import java.util.Date;
import java.util.List;

import com.baomidou.mybatisplus.core.conditions.update.LambdaUpdateWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ruoyi.common.core.domain.DlBaseEntity;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.SecurityUtils;
import com.ruoyi.member.domain.MemberUser;
import com.ruoyi.member.service.IMemberUserService;
import com.ruoyi.member.vo.MemberApplyVO;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.ruoyi.member.mapper.MemberApplyMapper;
import com.ruoyi.member.domain.MemberApply;
import com.ruoyi.member.service.IMemberApplyService;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;

/**
 * 通告主认证申请Service业务层处理
 * 
 * @author pqz
 * @date 2025-03-17
 */
@Service
public class MemberApplyServiceImpl extends ServiceImpl<MemberApplyMapper,MemberApply>  implements IMemberApplyService
{
    @Autowired
    private MemberApplyMapper memberApplyMapper;
    @Resource
    private IMemberUserService memberUserService;


    /**
     * 通告主认证申请列表查询
     *
     * @param memberApply {@link MemberApplyVO}
     * @param page        分页参数
     * @return com.baomidou.mybatisplus.core.metadata.IPage<com.ruoyi.member.domain.MemberApply>
     * @author PQZ
     * @date 9:53 2025/3/18
     **/
    @Override
    public IPage<MemberApplyVO> queryListPage(MemberApplyVO memberApply, Page<MemberApply> page) {
        return memberApplyMapper.queryListPage(memberApply,page);
    }

    /**
     * 审核通告主
     *
     * @param memberApply {@link MemberApplyVO}
     * @author PQZ
     * @date 11:50 2025/3/18
     **/
    @Override
    @Transactional(rollbackFor = Exception.class)
    public void checkMemberApply(MemberApplyVO memberApply) {
        //获取当前登录用户id
        Long userId = SecurityUtils.getUserId();
        //当前时间
        Date nowDate = new Date();
        memberApply.setApprovalUserId(userId);
        memberApply.setApprovalTime(nowDate);
        updateById(memberApply);
        //通过userId更新会员表身份类型
        LambdaUpdateWrapper<MemberUser> lambdaUpdateWrapper = new LambdaUpdateWrapper<>();
        lambdaUpdateWrapper.eq(MemberUser::getUserId,memberApply.getUserId())
                .eq(DlBaseEntity::getDelFlag,0)
                .eq(MemberUser::getUserType,"01")
                .set(MemberUser::getIdentityType,memberApply.getIdentityType());
        memberUserService.update(lambdaUpdateWrapper);
    }
}
